@@ -2,12 +2,13 @@
 
 from __future__ import unicode_literals
 
+import django
 
 __author__ = 'Dmitriy Sokolov'
-__version__ = '0.6.4'
+__version__ = '0.8.1'
 
-
-default_app_config = 'rangefilter.apps.RangeFilterConfig'
+if django.VERSION < (3, 2):
+    default_app_config = 'rangefilter.apps.RangeFilterConfig'
 
 
 VERSION = __version__
